Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3983)

Unified Diff: chrome/browser/chromeos/extensions/external_filesystem_apitest.cc

Issue 11359217: Move scoped_temp_dir from base to base/files (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/extensions/external_filesystem_apitest.cc
diff --git a/chrome/browser/chromeos/extensions/external_filesystem_apitest.cc b/chrome/browser/chromeos/extensions/external_filesystem_apitest.cc
index 159b57ed7775ab46303e929353d373894d74b85e..fecc9ef0e5c9fc339bf2d6fb41874381855c334b 100644
--- a/chrome/browser/chromeos/extensions/external_filesystem_apitest.cc
+++ b/chrome/browser/chromeos/extensions/external_filesystem_apitest.cc
@@ -5,11 +5,11 @@
#include "base/bind.h"
#include "base/file_path.h"
#include "base/file_util.h"
+#include "base/files/scoped_temp_dir.h"
#include "base/json/json_file_value_serializer.h"
#include "base/memory/scoped_ptr.h"
#include "base/message_loop_proxy.h"
#include "base/path_service.h"
-#include "base/scoped_temp_dir.h"
#include "base/threading/worker_pool.h"
#include "base/values.h"
#include "chrome/browser/chromeos/drive/drive_file_system.h"
@@ -254,7 +254,7 @@ class RestrictedFileSystemExtensionApiTest : public ExtensionApiTest {
}
protected:
- ScopedTempDir tmp_dir_;
+ base::ScopedTempDir tmp_dir_;
FilePath mount_point_dir_;
};
@@ -293,7 +293,7 @@ class RemoteFileSystemExtensionApiTest : public ExtensionApiTest {
}
protected:
- ScopedTempDir test_cache_root_;
+ base::ScopedTempDir test_cache_root_;
google_apis::MockDriveService* mock_drive_service_;
};
@@ -321,10 +321,10 @@ IN_PROC_BROWSER_TEST_F(FileSystemExtensionApiTest, FileBrowserWebIntentTest) {
AddTmpMountPoint();
ResultCatcher catcher;
- ScopedTempDir tmp_dir;
+ base::ScopedTempDir tmp_dir;
ASSERT_TRUE(tmp_dir.CreateUniqueTempDir());
// Create a test file inside the ScopedTempDir.
FilePath test_file = tmp_dir.path().AppendASCII("text_file.xul");
CreateFileWithContent(test_file, kTestFileContent);
@@ -321,10 +321,10 @@ IN_PROC_BROWSER_TEST_F(FileSystemExtensionApiTest, FileBrowserWebIntentTest) {
ASSERT_TRUE(tmp_dir.CreateUniqueTempDir());
- // Create a test file inside the ScopedTempDir.
+ // Create a test file inside the base::ScopedTempDir.
FilePath test_file = tmp_dir.path().AppendASCII("text_file.xul");
CreateFileWithContent(test_file, kTestFileContent);

Powered by Google App Engine
This is Rietveld 408576698